#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const meow = require('meow');
const updateNotifier = require('update-notifier');
const chalk = require('chalk');
const cli = meow(`

    -----------------------------------------------------------
        **********  ********        ******** ****     ****
            **     **              **        ** **   ** **
            **     **              **        **  ** **  **
            **     ********* ***** ********* **   ***   **
            **            **              ** **    *    **
            **            **              ** **         **
            **     ********        ********  **         **                                                                
    ------------------------------------------------------------
    London Development Studio's                   TS-SM - v1.2.0
    ------------------------------------------------------------

    Usage
    ====================================

      $ ng2-sm <` + chalk.blue(`command`) + `> <` + chalk.cyan(`option`) + `>
      
    Commands
    ====================================
      
      By default all task need the project root to be specified
       --project -p | (Required) | Project to target (Dir)

      ` + chalk.blue(`build`) + ` - Will Build Our Node Submodule From Src -> Dist
      -----------------------------------------------------------------
       --watch   -w       | Watch our src folders 
       --clean   -c       | Clean our target before new build
       --local   -l       | Use local dependency number (Mainly for publishing)
       --debug   -d       | Show extra output for debuging

      ` + chalk.blue(`link`) + ` - Will run npm link in each sub module dist folder
      -----------------------------------------------------------------
       --watch   -w       | Watch our src folders 
       --deep             | By default local sub modules will be linked to each other
       --here    -h       | Link all sub modules to root package or here

      ` + chalk.blue(`publish`) + ` - Will run npm publish in each sub module dist dir
      -----------------------------------------------------------------
       --clean   -c       | Clean our target before new build
       --local   -l       | Use local dependency number (Mainly for publishing)
       --any-branch       | Disables on 'master' check
       --skip-git-check   | To skip all git checks
       --yarn             | To install dependencies with 'yarn'
       --skip-cleanup     | To not delete 'node_modules' before installing
       --skip-publish     | Skip publishing and clean build, in case you want to double check something
       --tag              | Same as 'npm publish --tag next', use in case you want new release without changing 'latest' npm tag
       --access           | Same as 'npm publish --access p*'
       ` + chalk.yellow(`
       ------------------------------------------------------------------------------------------------------------
       > (1.Run Git PreChecks)->(2.Clean Install Deps)->(3.Run Tests)->(4.Run e2e Tests)->(5.Publish Clean Build) <
       >  Steps 1-4 can be skipped with --yolo flag                                                               <
       ------------------------------------------------------------------------------------------------------------
      `) + `
      ` + chalk.blue(`version`) + ` - Will run npm version in each sub module and then the root folder
      -----------------------------------------------------------------
       --message -m         | Message to add to the version release 
       --no-git-tag-version | Do not create a version commit and tag(Applied only to the root folder)
       --skip-push          | Skip pushing of the version commit and tags
          
`, {
    alias: {
        m: 'message',
        p: 'project',
        w: 'watch',
        v: 'version',
        h: 'here',
        d: 'debug',
        c: 'clean',
        local: 'use-local-dependencies alias'
    }
});
updateNotifier({ pkg: cli.pkg }).notify();
if (cli.flags.version) {
    console.log(`${cli.pkg.name} ${cli.pkg.version}`);
    process.exit();
}
// console.log(chalk.red('ERROR:'), 'Some Error');
// console.log(chalk.yellow('WARN:'), 'Some Error');
// console.log(chalk.magenta('DEBUG:'), 'Some Error');
// show help and exit by default
if (cli.input.length === 0) {
    cli.showHelp(0);
}
// project flag is mandatory for now
if (!cli.flags.project) {
    console.error(chalk.red('ERROR:'), 'Please provide path to your projects source folder, `-p DIR` ');
    process.exit(1);
}
cli.flags.debug = !cli.flags.debug ? false : cli.flags.debug;
const ts_sm_1 = require("../lib/ts-sm");
Promise
    .resolve()
    .then(() => {
    // default verbose to true
    cli.flags.verbose = cli.flags.verbose !== false;
    return ts_sm_1.main(cli.input[0], cli);
})
    .catch(err => {
    console.error(chalk.red('ERROR:'), `\n`, err.stderr || err);
    process.exit(1);
});
