// todo: add load from config file, TBD
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const Listr = require('listr');
const cpy = require('cpy');
const del = require('del');
const chalk = require('chalk');
const npm_sm_1 = require("npm-sm");
const tasks_1 = require("../tasks");
function buildCommand({ project, verbose, clean, local, debug }) {
    // 1. clean dist folders
    // 2.1 merge pkg json
    // todo: 2.2 validate pkg (main, module, types fields)
    // 2.3 write pkg
    // 3. compile ts
    return npm_sm_1.findSubmodules(project, { local })
        .then(opts => new Listr([
        {
            title: 'Task: ' + chalk.blue('Clean dist folders'),
            task: () => new Listr(opts.map(opt => ({
                title: 'Cleaning:' + chalk.cyan(` ${opt.dist}`),
                task: () => del(opt.dist)
            }))),
            skip: () => !clean
        },
        {
            title: 'Task: ' + chalk.blue('Copy markdown files and license'),
            task: () => Promise.all(opts.map(opt => cpy(['*.md', 'LICENSE'], opt.dist)
                .then(() => cpy([path.join(opt.src, '*.md'),
                path.join(opt.src, 'LICENSE')], opt.dist))))
        },
        {
            title: 'Task: ' + chalk.blue("Build package.json files"),
            task: () => npm_sm_1.buildPkgs(opts, { local })
        },
        {
            title: 'Task: ' + chalk.blue('Build project files'),
            task: () => new Listr(opts.map(opt => ({
                title: 'Building: ' + chalk.cyan(`${opt.pkg.name} (${opt.src})`),
                task: () => tasks_1.build(opt.project, debug)
            })))
        }
    ], { renderer: verbose ? 'verbose' : 'default' }));
}
exports.buildCommand = buildCommand;
function buildTsRun(cli) {
    const { project, watch, verbose, clean, local, debug } = cli.flags;
    if (cli.flags.debug) {
        console.log(chalk.bgMagenta('[TS-SM] DEBUG:'), chalk.magenta('Project Src [' + project + ']'));
        console.log(chalk.bgMagenta('[TS-SM] DEBUG:'), chalk.magenta('Should Watch [' + watch + ']'));
        console.log(chalk.bgMagenta('[TS-SM] DEBUG:'), chalk.magenta('Should Clean [' + clean + ']'));
        console.log(chalk.bgMagenta('[TS-SM] DEBUG:'), chalk.magenta('From Local [' + clean + ']'));
    }
    return buildCommand({ project, verbose, clean, local, debug })
        .then(tasks => npm_sm_1.tasksWatch({ project, tasks, watch }));
}
exports.buildTsRun = buildTsRun;
